SyncConfig class

Sync configuration class for controlling which feature flags to fetch.

Constructors

SyncConfig({List<String> names = const [], List<String> prefixes = const []})
Creates a new SyncConfig instance passing an optional list of names and prefixes.
SyncConfig.flagSets(List<String> sets)
Creates a new SyncConfig instance passing a list of flag sets.
SyncConfig.fromSet({Set<String> names = const {}, Set<String> prefixes = const {}})
Creates a new SyncConfig instance passing an optional set of names and prefixes.

Properties

hashCode → int
The hash code for this object.
no setterinherited
names → Set<String>
Names of the feature flags to fetch.
no setter
prefixes → Set<String>
Prefixes of the feature flags to fetch.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sets → Set<String>
Flag sets of the feature flags to fetch.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited